==> yos.core-2.2.1.jar: restcontroller/sysmanage/develop/userauth/SQL/获取角色应用授权.sql <==
select distinct t.systemmoduleid, t.systemappid, t.systemapp, t.systemappname, t.apppath,t.apppath_index, t.sequence,t.isdatatag,t.isdatateam,t.istask,t.isdatafollowup
from (
         select distinct t4.systemmoduleid, t3.systemappid, t3.systemapp, t3.systemappname, t3.apppath,t3.apppath_index, t3.sequence,t3.isdatatag,t3.isdatateam,t3.istask,t3.isdatafollowup
         from sys_roleappoptionauth t1
                  inner join sys_systemapp_options t2 on t1.optionid = t2.optionid and t2.isused = 1
                  inner join sys_systemapp t3 on t2.systemappid = t3.systemappid and t3.isused = 1
                  inner join sys_systemmodule t4 on t3.systemmoduleid = t4.systemmoduleid and t4.isused = 1
                  inner join sys_systemclient t5 on t4.systemclientid = t5.systemclientid and t5.isused = 1
         where t5.systemclient = $systemclient$
           and exists(select * from sys_userrole where roleid = t1.roleid and userid = $userid$ and siteid = $siteid$)
         union all
         select distinct t1.systemmoduleid, t1.systemappid, t1.systemapp, t1.systemappname, t1.apppath,t1.apppath_index, t1.sequence,t1.isdatatag,t1.isdatateam,t1.istask,t1.isdatafollowup
         from sys_systemapp t1
                  inner join sys_systemmodule t2 on t1.systemmoduleid = t2.systemmoduleid and t2.isused = 1
                  inner join sys_systemclient t3 on t2.systemclientid = t3.systemclientid and t3.isused = 1
         where t1.isused = 1
           and t1.isneedauth = 0
           and t3.systemclient = $systemclient$) t
order by t.sequence

==> yos.core-2.3.0.jar: restcontroller/sysmanage/develop/userauth/SQL/获取角色应用授权.sql <==
select distinct t.systemmoduleid, t.systemappid, t.systemapp, t.systemappname, t.apppath,t.apppath_index, t.sequence,t.isdatatag,t.isdatateam,t.istask,t.isdatafollowup
from (
         select distinct t4.systemmoduleid, t3.systemappid, t3.systemapp, t3.systemappname, t3.apppath,t3.apppath_index, t3.sequence,t3.isdatatag,t3.isdatateam,t3.istask,t3.isdatafollowup
         from sys_roleappoptionauth t1
                  inner join sys_systemapp_options t2 on t1.systemappid=t2.systemappid and t1.optionid = t2.optionid and t2.isused = 1
                  inner join sys_systemapp t3 on t2.systemappid = t3.systemappid and t3.isused = 1
                  inner join sys_systemmodule t4 on t3.systemmoduleid = t4.systemmoduleid and t4.isused = 1
                  inner join sys_systemclient t5 on t4.systemclientid = t5.systemclientid and t5.isused = 1
         where t5.systemclient = $systemclient$
           and exists(select * from sys_userrole where roleid = t1.roleid and userid = $userid$ and siteid = $siteid$)
         union all
         select distinct t1.systemmoduleid, t1.systemappid, t1.systemapp, t1.systemappname, t1.apppath,t1.apppath_index, t1.sequence,t1.isdatatag,t1.isdatateam,t1.istask,t1.isdatafollowup
         from sys_systemapp t1
                  inner join sys_systemmodule t2 on t1.systemmoduleid = t2.systemmoduleid and t2.isused = 1
                  inner join sys_systemclient t3 on t2.systemclientid = t3.systemclientid and t3.isused = 1
         where t1.isused = 1
           and t1.isneedauth = 0
           and t3.systemclient = $systemclient$) t
order by t.sequence
